# -*- coding: UTF-8 -*-
'''
@作者 ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
@微信 ：CoderWanFeng : https://mp.weixin.qq.com/s/B1V6KeXc7IOEB8DgXLWv3g
@个人网站 ：www.python-office.com
@Date    ：2023/4/23 23:01 
@Description     ：
'''
from time import sleep

from pywinauto.application import *
from pywinauto.base_wrapper import *
from pywinauto.controls.uiawrapper import UIAWrapper
from pywinauto.keyboard import send_keys
from pywinauto.uia_element_info import UIAElementInfo

from PyOfficeRobot.lib.decorator_utils.instruction_url import instruction


def _Carry_TXL(App_Object, Hello_Str, Tel_Number, notes):
    """
    该函数为申请好友验证时的函数胡\n
    :param App_Object: 微信窗口操作对象
    :param Hello_Str: 打招呼的字符串
    :param Tel_Number: 备注名,用于备注该用户的手机号码
    :param notes: 备注名
    :return: None
    """
    # <editor-fold desc="代码块 : 填写验证信息以及确认操作">
    # Anchor为锚点 Target为目标点
    Anchor_1 = App_Object.child_window(title='发送添加朋友申请')
    Anchor_1.draw_outline(colour='green', thickness=5)
    Anchor_1_Wrapper = Anchor_1.wrapper_object()
    Anchor_1_Wrapper_Parent = Anchor_1_Wrapper.element_info.parent
    Children_1 = Anchor_1_Wrapper_Parent.children()
    Target_1 = Children_1[1]
    Target_1_Wrapper = UIAWrapper(Target_1)
    Target_1_Wrapper.draw_outline(colour='red', thickness=5)
    Target_1_Wrapper.click_input()
    Target_1_Wrapper.click_input()
    for _ in range(50):
        send_keys("{VK_END}")
        send_keys("{VK_BACK}")
    Target_1_Wrapper.type_keys(Hello_Str)

    Anchor_2 = App_Object.child_window(title='备注名')
    Anchor_2.draw_outline(colour='green', thickness=5)
    Anchor_2_Wrapper = Anchor_2.wrapper_object()
    Anchor_2_Wrapper_Parent = Anchor_2_Wrapper.element_info.parent
    Children_2 = Anchor_2_Wrapper_Parent.children()
    Target_2 = Children_2[1]
    Target_2_Wrapper = UIAWrapper(Target_2)
    Target_2_Wrapper.draw_outline(colour='red', thickness=5)
    Target_2_Wrapper.click_input()
    Target_2_Wrapper.click_input()
    for _ in range(30):
        send_keys("{VK_END}")
        send_keys("{VK_BACK}")
    Target_2_Wrapper.type_keys(notes)
    # </editor-fold>
    # App_Object.capture_as_image().save(Tel_Number + ".jpg")

    Button_Yes = App_Object.child_window(title='确定')
    Button_Yes_Wrapper = Button_Yes.wrapper_object()
    Button_Yes_Wrapper.draw_outline(colour='red', thickness=5)
    Button_Yes_Wrapper.click_input()


def Get_NowTime():
    "【当前时间：%s-%s-%s-：%s:%s:%s】正在读取第%s行数据,该公司的联系电话有如下:\n【%s】"
    return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())


def _find_friend(WX_Windows, Tel_Number, ErrorCount):
    """
    该函数用于在进入通讯录界面,输入手机号码一系列的操作\n
    :param WX_Windows: 微信窗口对象
    :param Tel_Number: 需要搜索的手机号码
    :param ErrorCount:
    :return:
    """
    # <editor-fold desc="代码块 : 执行搜索手机号码操作">
    print("提示:当前在正在对输入的手机号码进行一个查找")
    Button_AddFrient = WX_Windows.child_window(title="添加朋友")
    Button_AddFrient_Wrapper = Button_AddFrient.wrapper_object()
    """:type : pywinauto.controls.uiawrapper.UIAWrapper"""
    Button_AddFrient_Wrapper.draw_outline(colour='red', thickness=5)
    Button_AddFrient_Wrapper.click_input()

    Edit_Number = WX_Windows.child_window(title="微信号/手机号")
    Edit_Number_Wrapper = Edit_Number.wrapper_object()
    """:type : pywinauto.controls.uiawrapper.UIAWrapper"""
    Edit_Number_Wrapper.draw_outline(colour='red', thickness=5)
    Edit_Number_Wrapper.click_input()
    Edit_Number_Wrapper.type_keys(Tel_Number)

    Button_Find = WX_Windows.child_window(title='搜索：' + Tel_Number)
    Button_Find_Wrapper = Button_Find.wrapper_object()
    """:type : pywinauto.controls.uiawrapper.UIAWrapper"""
    Button_Find_Wrapper.draw_outline(colour='red', thickness=5)
    Button_Find_Wrapper.click_input()

    try:

        Button_AddTXL = WX_Windows.child_window(title='添加到通讯录')
        Button_AddTXL_Wrapper = Button_AddTXL.wrapper_object()
        """:type : pywinauto.controls.uiawrapper.UIAWrapper"""
        Button_AddTXL_Wrapper.draw_outline(colour="red", thickness=5)
        Button_AddTXL_Wrapper.click_input()
        print("提示:当前号码[ %s ]可以进行一个添加" % (Tel_Number))

        return True
    except:
        try:
            print(
                "错误:当前号码出现错误,可能原因为 1.已经添加过该好友  2.该号码不存在  3.出现频繁次数了  当前号码为 : %s" % (
                    Tel_Number))
            print("注意:当前出错次数为 : %d" % (ErrorCount))

            find_result = WX_Windows.child_window(title=r'搜索结果')
            find_result_wrapper = find_result.wrapper_object()
            assert isinstance(find_result_wrapper, UIAWrapper)
            find_childs = find_result_wrapper.children()

            if (len(find_childs) == 1):
                print("\t\t 【警告】：%s-----当前号码并没有进行一个点击,请后续再进行操作" % (Get_NowTime()))

            elif (len(find_childs) == 2):
                find_childs[0].draw_outline(colour='red', thickness=5)
                find_resule_info = find_childs[0].element_info
                assert isinstance(find_resule_info, UIAElementInfo)
                print("\t\t 【错误】：%s-----%s" % (Get_NowTime(), find_resule_info.name))
                print("\t\t 【错误】：%s-----%s" % (Get_NowTime(), find_resule_info.name))

        except:
            print("\t\t %s提示:当前遍历号码[ %s ]已经是微信好友" % (Get_NowTime(), Tel_Number))
            print("\t\t %s提示:当前遍历号码[ %s ]已经是微信好友" % (Get_NowTime(), Tel_Number))

        return False
    # </editor-fold>


def _Open_TXL(Button_LT_Wrapper, Button_TXL_Wrapper, Button_SC_Wrapper, Button_EXE_Wrapper):
    # <editor-fold desc="代码块 : 进入通讯录界面">
    """
    该函数为打开通讯录界面\n
    :return:
    """
    print("提示:当前正在进入通讯录界面")
    Button_SC_Wrapper.draw_outline(colour="red", thickness=5)
    Button_SC_Wrapper.click_input()
    sleep(0.5)
    Button_EXE_Wrapper.draw_outline(colour="red", thickness=5)
    Button_EXE_Wrapper.click_input()
    sleep(0.5)
    Button_LT_Wrapper.draw_outline(colour="red", thickness=5)
    Button_LT_Wrapper.click_input()
    sleep(0.5)
    Button_EXE_Wrapper.draw_outline(colour="red", thickness=5)
    Button_EXE_Wrapper.click_input()
    sleep(0.5)
    Button_TXL_Wrapper.draw_outline(colour="red", thickness=5)
    Button_TXL_Wrapper.click_input()
    sleep(0.5)
    # </editor-fold>


@instruction
def add(num_notes, msg):
    # <editor-fold desc="代码块 : 获取微信窗口句柄">
    Get_WeChat_Hwnd = lambda: win32gui.FindWindow("WeChatMainWndForPC", "微信")
    WeChat_Hwnd = Get_WeChat_Hwnd()
    # </editor-fold>

    # <editor-fold desc="代码块 : 设置窗口状态以及位置">
    win32gui.ShowWindow(WeChat_Hwnd, 9)
    # win32gui.SetWindowPos(WeChat_Hwnd, win32con.HWND_TOPMOST, 0,0,800,800, win32con.SWP_NOMOVE | win32con.SWP_NOACTIVATE| win32con.SWP_NOOWNERZORDER|win32con.SWP_SHOWWINDOW)
    win32gui.MoveWindow(WeChat_Hwnd, 1920 - 800, 0, 800, 800, True)
    print("Msg:窗口设置完毕")
    # </editor-fold>

    # <editor-fold desc="代码块 : 获取微信窗口对象以及微信窗口的动作操作包装对象">
    App_Object = Application(backend="uia").connect(handle=WeChat_Hwnd)
    WX_Windows = App_Object['微信']
    """:type : pywinauto.application.WindowSpecification"""
    WX_Wrapper = WX_Windows.wrapper_object()
    """:type : pywinauto.controls.uiawrapper.UIAWrapper"""
    WX_Wrapper.draw_outline(colour="red", thickness=5)
    # </editor-fold>

    # <editor-fold desc="代码块 : 获取左侧按钮对象以及操作包装对象(合计:3对)">
    Button_LT = WX_Windows.child_window(title='聊天')
    Button_TXL = WX_Windows.child_window(title='通讯录')
    Button_SC = WX_Windows.child_window(title='收藏')
    Button_EXE = WX_Windows.child_window(title='小程序面板')

    Button_LT_Wrapper = Button_LT.wrapper_object()
    Button_TXL_Wrapper = Button_TXL.wrapper_object()
    Button_SC_Wrapper = Button_SC.wrapper_object()
    Button_EXE_Wrapper = Button_EXE.wrapper_object()

    Count = 1
    # </editor-fold>
    for num in num_notes.keys():
        _Open_TXL(Button_LT_Wrapper, Button_TXL_Wrapper, Button_SC_Wrapper, Button_EXE_Wrapper)
        result = _find_friend(WX_Windows=WX_Windows, Tel_Number=num, ErrorCount=Count)
        _Carry_TXL(App_Object=WX_Windows, Hello_Str=msg,
                   Tel_Number=num, notes=num_notes[num])


if __name__ == "__main__":
    msg = "你好，我是程序员晚枫，全网同名。"
    # num_list = ['15603052573', '19112440257']
    num_notes = {
        # 'CoderWanFeng': '北京-晚枫-学生',
        'hdylw1024': '上海-晚枫-乞丐',
    }
    add(msg=msg, num_notes=num_notes)



import datetime
import os

import poai
import porobot as porobot
import schedule

from PyOfficeRobot.core.WeChatType import WeChat
from PyOfficeRobot.lib.decorator_utils.instruction_url import instruction

wx = WeChat()


# @act_info(ACT_TYPE.MESSAGE)
@instruction
def send_message(who: str, message: str) -> None:
    """
    给指定人，发送一条消息
    :param who:
    :param message:
    :return:
    """

    # 获取会话列表
    wx.GetSessionList()
    wx.ChatWith(who)  # 打开`who`聊天窗口
    # for i in range(10):
    wx.SendMsg(message, who)  # 向`who`发送消息：你好~


@instruction
def chat_by_keywords(who: str, keywords: str):
    wx.GetSessionList()  # 获取会话列表
    wx.ChatWith(who)  # 打开`who`聊天窗口
    temp_msg = ''
    while True:
        try:
            friend_name, receive_msg = wx.GetAllMessage[-1][0], wx.GetAllMessage[-1][1]  # 获取朋友的名字、发送的信息
            if (friend_name == who) & (receive_msg != temp_msg) & (receive_msg in keywords.keys()):
                """
                条件：
                朋友名字正确:(friend_name == who)
                不是上次的对话:(receive_msg != temp_msg)
                对方内容在自己的预设里:(receive_msg in kv.keys())
                """

                temp_msg = receive_msg
                wx.SendMsg(keywords[receive_msg], who)  # 向`who`发送消息
        except:
            pass


@instruction
def receive_message(who='文件传输助手', txt='userMessage.txt', output_path='./'):
    wx.GetSessionList()  # 获取会话列表
    wx.ChatWith(who)  # 打开`who`聊天窗口
    while True:
        friend_name, receive_msg = wx.GetAllMessage[-1][0], wx.GetAllMessage[-1][1]  # 获取朋友的名字、发送的信息
        current_time = datetime.datetime.now()
        cut_line = '^^^----------^^^'
        print('--' * 88)
        with open(os.path.join(output_path, txt), 'a+') as output_file:
            output_file.write('\n')
            output_file.write(cut_line)
            output_file.write('\n')
            output_file.write(str(current_time))
            output_file.write('\n')
            output_file.write(str(friend_name))
            output_file.write('\n')
            output_file.write(str(receive_msg))
            output_file.write('\n')


@instruction
def send_message_by_time(who, message, time):
    schedule.every().day.at(time).do(send_message, who=who, message=message)
    while True:
        schedule.run_pending()


@instruction
def chat_by_gpt(who, api_key, model_engine="text-davinci-002", max_tokens=1024, n=1, stop=None, temperature=0.5,
                top_p=1,
                frequency_penalty=0.0, presence_penalty=0.6):
    wx.GetSessionList()  # 获取会话列表
    wx.ChatWith(who)  # 打开`who`聊天窗口
    temp_msg = None
    while True:
        try:
            friend_name, receive_msg = wx.GetAllMessage[-1][0], wx.GetAllMessage[-1][1]  # 获取朋友的名字、发送的信息
            if (friend_name == who) & (receive_msg != temp_msg):
                """
                条件：
                朋友名字正确:(friend_name == who)
                不是上次的对话:(receive_msg != temp_msg)
                对方内容在自己的预设里:(receive_msg in kv.keys())
                """
                print(f'【{who}】发送：【{receive_msg}】')
                temp_msg = receive_msg
                reply_msg = poai.chatgpt.chat(api_key, receive_msg,
                                              model_engine, max_tokens, n, stop, temperature,
                                              top_p, frequency_penalty, presence_penalty)
                wx.SendMsg(reply_msg, who)  # 向`who`发送消息
        except:
            pass


@instruction
def chat_robot(who):
    wx.GetSessionList()  # 获取会话列表
    wx.ChatWith(who)  # 打开`who`聊天窗口
    temp_msg = None
    while True:
        try:
            friend_name, receive_msg = wx.GetAllMessage[-1][0], wx.GetAllMessage[-1][1]  # 获取朋友的名字、发送的信息
            if (friend_name == who) & (receive_msg != temp_msg):
                """
                条件：
                朋友名字正确:(friend_name == who)
                不是上次的对话:(receive_msg != temp_msg)
                对方内容在自己的预设里:(receive_msg in kv.keys())
                """
                print(f'【{who}】发送：【{receive_msg}】')
                temp_msg = receive_msg
                reply_msg = porobot.normal.chat(receive_msg)
                wx.SendMsg(reply_msg, who)  # 向`who`发送消息
        except:
            pass



from PyOfficeRobot.core.WeChatType import WeChat
from PyOfficeRobot.lib.decorator_utils.instruction_url import instruction

wx = WeChat()


# @act_info(ACT_TYPE.FILE)
@instruction
def send_file(who: str, file: str):
    """
    发送任意类型的文件
    :param who:
    :param file: 文件路径
    :return:
    """
    wx.ChatWith(who)  # 打开聊天窗口
    # wx.SendFiles(file)
    wx.test_SendFiles(filepath=file, who=who)  # 添加who参数：雷杰

    # 注：为保证发送文件稳定性，首次发送文件可能花费时间较长，后续调用会缩短发送时间


import uiautomation as uia

""" isinstance()函数知识点:

type判断函数类型是什么，而isinstance是通过判断对象是否是已知的类型
但是isinstance比type高级一些（功能上的差异）
type() ，不考虑继承关系（子类不是父类类型）
isinstance() ，考虑继承关系（子类是父类类型）

a = 10086
isinstance (a,int)  # true
isinstance (a,str) # false
isinstance (a,(str,int,list))    # 只要满足元组类型中的其中一个即可，答案是满足，所以为false
"""


def get_group_list():
    """
    author: Zijian
    :return:
    """
    uia.uiautomation.SetGlobalSearchTimeout(2)
    wechat_win = uia.WindowControl(Depth=1, Name="微信", ClassName="WeChatMainWndForPC")
    wechat_win.SwitchToThisWindow()
    wechat_win.SetActive()
    wechat_win.SetTopmost()

    ### 点击右上角"聊天信息"
    chatinfo_button = wechat_win.ButtonControl(Name="聊天信息")
    chatinfo_button.Click(waitTime=0.5)

    ### 点击下拉菜单按钮"查看更多" 如果群里人数少这个按钮可能不存在
    more_button = wechat_win.ButtonControl(Name="查看更多")
    if more_button.Exists(0, 0):
        more_button.Click(0, 0, simulateMove=False)

    ### 获取"群聊名称"   先定位"群聊名称",再获取下一个兄弟节点,再获取第一个子节点,.Name取出里面的文字
    group_name = wechat_win.TextControl(Name="群聊名称").GetNextSiblingControl().GetFirstChildControl().Name
    print(group_name)

    ### 获取聊天成员列表控件,并且要获取边框范围
    nums = wechat_win.ListControl(Name="聊天成员")
    rect = nums.GetParentControl().BoundingRectangle  # 获取父级范围
    print(rect)
    numbers = nums.GetChildren()
    # for member in numbers:
    sum_info = []
    for index, member in enumerate(numbers):
        # print(type(member))
        # print(uia.ListItemControl)

        # 判断列表的每一个子成员 是不是列表项目控件,如果不是就跳过
        if not isinstance(member, uia.ListItemControl):
            continue

        # 判断列表的每一个子成员 是不是列表项目控件的名称是否存在名字,或有添加,删除,移除的关键字,如果不是就跳过。
        if not member.Name or member.Name in ("添加", "删除", "移出"):
            continue

        # 再判断当前时候有 快捷键被按下的状态,如果有直接break跳出循环停止采集.
        if uia.IsKeyPressed(uia.Keys.VK_F2):
            print("F2已被按下，停止采集")
            break

        # print("  -------  " + member.Name + "  -------  ")
        # 判断 每个成员的边界底部是否超出整个列表成员控件边框的底部,如果超过就发送下滚轮热键
        pos = member.BoundingRectangle
        if pos.bottom >= rect.bottom:
            uia.WheelDown(waitTime=0.5)

        ### 先左键点击每个成员,再用右键点击取消
        # 左键点击每个成员
        member.Click(waitTime=0.01)

        # 左键后会出现一个窗格控件  WalkControl返回的是一个元组类型(control, depth)控件,换句话说就是一个长度为2的元组对象 for循环迭代器时需要用两个变量去接收 如果用一个变量去接受返回的是一个元组长度为2的对象

        user_info_pane = uia.PaneControl(Name="微信")
        # user_info_pane拿到用户信息弹窗后截图保存本地文件
        # user_info_pane.CaptureToImage(savePath=f"{index}.png")

        # 用户信息字典
        user_info = {}
        user_info['群列表显示'] = member.Name
        for control, depth in uia.WalkControl(user_info_pane):
            # print(control)  for循环迭代器时需要用两个变量去接收 如果用一个变量去接受返回的是一个元组对象长度为2的

            if control.ControlTypeName == "TextControl":
                # k = c.Name.rstrip("：")  #rstrip() 删除 string 字符串末尾的指定字符
                text = control.Name
                if "：" in text:  # 如果这个文本控件类型里面的文本包含中文冒号":",就Get他的下一个兄弟节点 再用·Name的方法取出里面的内容
                    k = text.rstrip("：")
                    v = control.GetNextSiblingControl().Name
                    # print(k,v)
                    user_info[k] = v
                if "来源" in text:
                    k = text
                    v = control.GetNextSiblingControl().Name
                    # print(k,v)
                    user_info[k] = v
                if "备注名" in text:
                    k = text
                    v = control.GetNextSiblingControl().Name
                    # print(k,v)
                    user_info[k] = v
                if "企业" == text:
                    k = text
                    a = control.GetNextSiblingControl()
                    v = a.GetNextSiblingControl().Name
                    # print(k,v)
                    user_info[k] = v
                if "实名" == text:
                    k = text
                    a = control.GetNextSiblingControl()
                    v = a.GetNextSiblingControl().Name
                    # print(k,v)
                    user_info[k] = v
                if "商城" == text:
                    k = text
                    v = control.GetNextSiblingControl().Name
                    # print(k,v)
                    user_info[k] = v
        print(user_info)
        sum_info.append(user_info)

        # 右键点击每个成员取消个人弹框 或者 发送ESC 快捷键
        # member.RightClick(waitTime=0.01)
        uia.SendKeys('{ESC}')

    print(sum_info)

    ### 将列表字典传给pandas库分析数据
    import pandas as pd
    save_path = "微信群信息采集.xlsx"

    df = pd.DataFrame(sum_info)
    df = df.reset_index(drop=True)  ### False是保留原先索引建立新的索引 True是重新建立索引
    df.to_excel(excel_writer=save_path, sheet_name='微信群信息采集', index=False)
    print(df)



# -*- codeing = utf-8 -*-
# @Time : 2023/3/14 18:18
# @Project_File : Start.py
# @Dir_Path : _____Release_File/微信自动化/微信群发消息
# @File : QT.py
# @IDE_Name : PyCharm 
# ============================================================
# ============================================================
# ============================================================
# ============================================================
# ============================================================

import sys
import threading

import xlrd
from PySide6.QtCore import QStringListModel, QModelIndex
from PySide6.QtWidgets import QApplication, QWidget
from PySide6.QtWidgets import QFileDialog

from PyOfficeRobot.api.chat import send_message
from PyOfficeRobot.core.group.ui_file_py import Ui_Form


# 继承QWidget类，以获取其属性和方法
class MyWidget(QWidget):
    def __init__(self):
        super().__init__()
        # 设置界面为我们生成的界面
        self.ui = Ui_Form()
        self.ui.setupUi(self)
        self.set_ui()

        self.sendtext: str = str()
        self.groupslist: list = list()
        self.groupslistfilename: str = str()
        self.sendtextfilename: str = str()
        self.state = True

    def set_ui(self):
        self.setWindowTitle("Python自动化办公社区")
        self.ui.pushButton_load.clicked.connect(self.OnPushbutton_load_Cliked)
        self.ui.pushButton_start.clicked.connect(self.OnPushbutton_Start_Cliked)
        self.ui.pushButton_close.clicked.connect(self._OnPushbutton_Close_Clicked)
        self.ui.listView.clicked.connect(self.test)

    def test(self, index: QModelIndex):
        count = self.model.rowCount()
        print(count)
        for _ in range(count):
            print(self.model.index(_).data())

    def OnPushbutton_load_Cliked(self):

        self.groupslist.clear()

        self.groupslistfilename = QFileDialog.getOpenFileName(caption='选择群发列表', filter='*.xls')[0]
        self.sendtextfilename = QFileDialog.getOpenFileName(caption='选择群发的文本', filter='*.txt')[0]

        # <editor-fold desc="代码段 ： 设置群发好友列表">
        work = xlrd.open_workbook(filename=self.groupslistfilename)
        sheet = work.sheet_by_index(0)
        for _ in range(sheet.nrows):
            itme = sheet.cell_value(_, 0)
            state = sheet.cell_value(_, 1)

            if state == "True":
                if itme != '':
                    self.groupslist.append(sheet.cell_value(_, 0))
        # </editor-fold>

        # <editor-fold desc="代码段 ：设置群发文本">
        file = open(file=self.sendtextfilename, encoding='utf-8')
        for _ in file.readlines():
            self.sendtext = self.sendtext + _ + '{ctrl}{ENTER}'
        # </editor-fold>

        # <editor-fold desc="代码段 : 设置群发列表到ui">
        self.model = QStringListModel()
        self.model.setStringList(self.groupslist)
        self.ui.listView.setModel(self.model)
        # </editor-fold>

    def threadfunction(self):
        for _ in self.groupslist:
            thread_start = threading.Thread(target=send_message, args=(_, self.sendtext))
            thread_start.start()
            thread_start.join()

    def OnPushbutton_Start_Cliked(self):
        self.thread_1 = threading.Thread(target=self.threadfunction)
        self.thread_1.start()

    def _OnPushbutton_Close_Clicked(self):
        sys.exit(0)


# 程序入口
if __name__ == "__main__":
    app = QApplication(sys.argv)
    # 初始化QApplication，界面展示要包含在QApplication初始化之后，结束之前

    window = MyWidget()
    window.show()
    # 初始化并展示我们的界面组件

    sys.exit(app.exec_())
    # 结束QApplication



# -*- coding: UTF-8 -*-
'''
@作者 ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
@微信 ：CoderWanFeng : https://mp.weixin.qq.com/s/B1V6KeXc7IOEB8DgXLWv3g
@个人网站 ：www.python-office.com
@Date    ：2023/4/27 21:50 
@Description     ：
'''

import sys

from PyOfficeRobot.lib.decorator_utils.instruction_url import instruction
from PySide6.QtWidgets import QApplication

from PyOfficeRobot.core.group.Start import MyWidget

@instruction
def send():
    app = QApplication(sys.argv)
    # 初始化QApplication，界面展示要包含在QApplication初始化之后，结束之前
    window = MyWidget()
    window.show()
    # 初始化并展示我们的界面组件
    sys.exit(app.exec_())
    # 结束QApplication



#!/usr/bin/env python
# -*- coding:utf-8 -*-

#############################################
# File Name: instruction_url.py
# Mail: 1957875073@qq.com
# Created Time:  2022-12-17 08:14:34
# Description: 有关 方法说明 的装饰器
#############################################

import os
# 每个文件的具体方法说明
from functools import wraps

from PyOfficeRobot.lib.CONST import SPLIT_LINE

chat_dict = {"chat_by_keywords": "https://www.bilibili.com/video/BV1fV4y1M7ju",
             "receive_message": "",
             "send_message": "https://www.bilibili.com/video/BV1Jt4y1j7F1",
             "send_message_by_time": "https://www.bilibili.com/video/BV1m8411b7LZ",
             "chat_by_gpt": "https://blog.51cto.com/u_15493782/6131326",
             "chat_robot": "https://www.bilibili.com/video/BV1Xa411u7yU",
             }
file_dict = {
    "send_file": "https://www.bilibili.com/video/BV1te4y1y7Ro",

}

friend_dict = {
    "add": "https://www.bilibili.com/video/BV1DV4y1o7t2",

}

group_dict = {
    "send": "https://www.bilibili.com/video/BV1Nm4y1C7N7",
}

# 有多少文件需要说明
instruction_file_dict = {
    "chat.py": chat_dict,
    "file.py": file_dict,
    "friend.py": friend_dict,
    "group.py": group_dict,
}


def instruction(func):
    @wraps(func)
    def instruction_wrapper(*args, **kwargs):
        func_filename = os.path.basename(func.__code__.co_filename)  # 取出方法所在的文件名
        # 如果有这个文件，并且已经配置了方法名对应的说明链接，则打印出来
        if func_filename in instruction_file_dict.keys() and instruction_file_dict[func_filename][func.__name__]:
            print(SPLIT_LINE)
            print('【PyOfficeRobot，微信机器人全部功能】：https://mp.weixin.qq.com/s/HIl7ZsldGc9Lp8JtCEzOpg')
            print(SPLIT_LINE)
            print(
                f'正在运行：PyOfficeRobot.{os.path.basename(func_filename)[:-3]}.{func.__name__} , 这个方法的使用说明：{instruction_file_dict[func_filename][func.__name__]}')
            print(SPLIT_LINE)
        instruction_res = func(*args, **kwargs)
        return instruction_res

    return instruction_wrapper


#############################################
# 以下是本文件的工具模块，用来更新方法和链接
from inspect import getmembers, isfunction


# 获取模块包含的方法名
def get_method_name(file):
    for method_name in getmembers(file):
        if isfunction(method_name[1]):
            print(f'"{method_name[0]}":"",')
